Crate waybar_cffi_sys

Crate waybar_cffi_sys 

Re-exports

pub use gtk;
pub use libc;

Structs

_GData
_GObject
_GTypeClass
GTypeClass:
_GTypeInstance
GTypeInstance:
_GtkContainer
_GtkContainerPrivate
_GtkWidget
_GtkWidgetPrivate
wbcffi_config_entry
Config key-value pair
wbcffi_init_info
Waybar module information
wbcffi_module

Statics

WAYBAR_VERSION
The version of Waybar the bindings were built against.
wbcffi_version
Waybar ABI version. 2 is the latest version

Functions

wbcffi_deinit
Module deinit/delete function, called when Waybar is closed or when the module is removed
wbcffi_doaction
Called on module action (see https://github.com/Alexays/Waybar/wiki/Configuration#module-actions-config)
wbcffi_init
Module init/new function, called on module instantiation
wbcffi_refresh
Called when Waybar receives a POSIX signal and forwards it to each module
wbcffi_update
Called from the GTK main event loop, to update the UI

Type Aliases

GData
GInitiallyUnowned
GType
GTypeClass
GTypeClass:
GTypeInstance
GTypeInstance:
GtkContainer
GtkContainerPrivate
GtkWidget
GtkWidgetPrivate
gsize
guint