Re-exports
Structs
- _GData
- _GObject
- _GType
Class - GTypeClass:
- _GType
Instance - GTypeInstance:
- _Gtk
Container - _Gtk
Container Private - _Gtk
Widget - _Gtk
Widget Private - wbcffi_
config_ entry - Config key-value pair
- wbcffi_
init_ info - Waybar module information
- wbcffi_
module
Statics
- WAYBAR_
VERSION - The version of Waybar the bindings were built against.
- wbcffi_
version ⚠ - Waybar ABI version. 2 is the latest version
Functions
- wbcffi_
deinit ⚠ - Module deinit/delete function, called when Waybar is closed or when the module is removed
- wbcffi_
doaction ⚠ - Called on module action (see https://github.com/Alexays/Waybar/wiki/Configuration#module-actions-config)
- wbcffi_
init ⚠ - Module init/new function, called on module instantiation
- wbcffi_
refresh ⚠ - Called when Waybar receives a POSIX signal and forwards it to each module
- wbcffi_
update ⚠ - Called from the GTK main event loop, to update the UI